=============================
django-projector installation
=============================

Refer to file located at ``docs/installation.rst`` in order to get detailed
information on how to get ``django-projector`` up and running.
